@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import logging
 import os
 
@@ -9,7 +7,6 @@ from dvc.output.base import OutputBase
 from dvc.remote.local import RemoteLOCAL
 from dvc.utils import relpath
 from dvc.utils.compat import fspath_py35
-from dvc.utils.compat import str
 from dvc.utils.compat import urlparse
 from dvc.utils.fs import path_isin
 
