@@ -1,6 +1,4 @@
 """Manages user prompts."""
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import logging
 import sys
