@@ -1,20 +1,17 @@
-from __future__ import unicode_literals
-
 import csv
 import errno
 import json
 import logging
 import os
+import io
 
 from jsonpath_ng.ext import parse
 
 from dvc.exceptions import NoMetricsError
 from dvc.exceptions import OutputNotFoundError
 from dvc.repo import locked
-from dvc.utils.compat import builtin_str
 from dvc.utils.compat import csv_reader
 from dvc.utils.compat import open
-from dvc.utils.compat import StringIO
 
 NO_METRICS_FILE_AT_REFERENCE_WARNING = (
     "Metrics file '{}' does not exist at the reference '{}'."
@@ -50,7 +47,7 @@ def _read_metric_hxsv(fd, hxsv_path, delimiter):
     row = indices[0]
     row = int(row) if row else None
     col = indices[1] if len(indices) > 1 and indices[1] else None
-    reader = list(csv.DictReader(fd, delimiter=builtin_str(delimiter)))
+    reader = list(csv.DictReader(fd, delimiter=delimiter))
     return _do_read_metric_xsv(reader, row, col)
 
 
@@ -59,7 +56,7 @@ def _read_metric_xsv(fd, xsv_path, delimiter):
     row = indices[0]
     row = int(row) if row else None
     col = int(indices[1]) if len(indices) > 1 and indices[1] else None
-    reader = list(csv.reader(fd, delimiter=builtin_str(delimiter)))
+    reader = list(csv.reader(fd, delimiter=delimiter))
     return _do_read_metric_xsv(reader, row, col)
 
 
@@ -104,7 +101,7 @@ def _format_csv(content, delimiter):
         "0.67528    0.289545        testing\n"
         "0.671502   0.297848        validation\n"
     """
-    reader = csv_reader(StringIO(content), delimiter=builtin_str(delimiter))
+    reader = csv_reader(io.StringIO(content), delimiter=delimiter)
     rows = [row for row in reader]
     max_widths = [max(map(len, column)) for column in zip(*rows)]
 
@@ -130,10 +127,10 @@ def _format_output(content, typ):
         str: Content in a raw or tabular format.
     """
 
-    if "csv" in str(typ):
+    if "csv" in typ:
         return _format_csv(content, delimiter=",")
 
-    if "tsv" in str(typ):
+    if "tsv" in typ:
         return _format_csv(content, delimiter="\t")
 
     return content
