@@ -1,5 +1,4 @@
 """Manages Git."""
-from __future__ import unicode_literals
 
 import logging
 import os
@@ -20,7 +19,6 @@ from dvc.utils import relpath
 from dvc.utils.fs import path_isin
 from dvc.utils.compat import cast_bytes_py2
 from dvc.utils.compat import open
-from dvc.utils.compat import str
 
 
 logger = logging.getLogger(__name__)
