@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import errno
 import logging
 import os
@@ -7,7 +5,6 @@ import shutil
 
 from dvc.utils.compat import fspath
 from dvc.utils.compat import open
-from dvc.utils.compat import str
 
 
 logger = logging.getLogger(__name__)
