@@ -1,5 +1,4 @@
 """Helpers for other modules."""
-from __future__ import unicode_literals
 
 import hashlib
 import json
@@ -9,20 +8,18 @@ import os
 import re
 import sys
 import time
+import io
 
 import colorama
 import nanotime
 from ruamel.yaml import YAML
 from shortuuid import uuid
 
-from dvc.utils.compat import builtin_str
 from dvc.utils.compat import cast_bytes_py2
 from dvc.utils.compat import fspath
 from dvc.utils.compat import fspath_py35
 from dvc.utils.compat import makedirs as _makedirs
 from dvc.utils.compat import open
-from dvc.utils.compat import str
-from dvc.utils.compat import StringIO
 
 
 logger = logging.getLogger(__name__)
@@ -93,16 +90,14 @@ def dict_filter(d, exclude=()):
     Exclude specified keys from a nested dict
     """
 
-    def fix_key(k):
-        return str(k) if isinstance(k, builtin_str) else k
-
     if isinstance(d, list):
         return [dict_filter(e, exclude) for e in d]
 
     if isinstance(d, dict):
-        items = ((fix_key(k), v) for k, v in d.items())
         return {
-            k: dict_filter(v, exclude) for k, v in items if k not in exclude
+            k: dict_filter(v, exclude)
+            for k, v in d.items()
+            if k not in exclude
         }
 
     return d
@@ -269,7 +264,7 @@ def fix_env(env=None):
 
 def tmp_fname(fname):
     """ Temporary name for a partial download """
-    return fspath(fname) + "." + str(uuid()) + ".tmp"
+    return fspath(fname) + "." + uuid() + ".tmp"
 
 
 def current_timestamp():
@@ -277,36 +272,19 @@ def current_timestamp():
 
 
 def from_yaml_string(s):
-    return YAML().load(StringIO(s))
+    return YAML().load(io.StringIO(s))
 
 
 def to_yaml_string(data):
-    stream = StringIO()
+    stream = io.StringIO()
     yaml = YAML()
     yaml.default_flow_style = False
     yaml.dump(data, stream)
     return stream.getvalue()
 
 
-def dvc_walk(top, dvcignore, topdown=True, onerror=None, followlinks=False):
-    """
-    Proxy for `os.walk` directory tree generator.
-    Utilizes DvcIgnoreFilter functionality.
-    """
-    top = fspath_py35(top)
-
-    for root, dirs, files in os.walk(
-        top, topdown=topdown, onerror=onerror, followlinks=followlinks
-    ):
-
-        if dvcignore:
-            dirs[:], files[:] = dvcignore(root, dirs, files)
-
-        yield root, dirs, files
-
-
-def walk_files(directory, dvcignore):
-    for root, _, files in dvc_walk(directory, dvcignore):
+def walk_files(directory):
+    for root, _, files in os.walk(fspath(directory)):
         for f in files:
             yield os.path.join(root, f)
 
@@ -425,8 +403,6 @@ def resolve_output(inp, out):
 
 
 def format_link(link):
-    import colorama
-
     return "<{blue}{link}{nc}>".format(
         blue=colorama.Fore.CYAN, link=link, nc=colorama.Fore.RESET
     )
